EnumDeserializer

Struct EnumDeserializer 

struct EnumDeserializer<M> {
    delegate: M,
    is_human_readable: bool,
}
Deserialize an enum from a map element

The Deserializer implementation is the starting point, which first calls the EnumAccess methods. The EnumAccess is used to deserialize the enum variant type of the enum. The VariantAccess is used to deserialize the value part of the enum.

Fields

delegate: Mis_human_readable: bool